@@ -1,3 +1,3 @@
-\echo -- q1
+/* -- q1 */
 SELECT ST_Area(pgr_alphaShape((SELECT ST_Collect(the_geom) FROM edge_table_vertices_pgr), 1.5));
-\echo -- q2
+/* -- q2 */
