@@ -1,27 +1,27 @@
-\echo --q1
+/* -- q1 */
 SELECT * FROM pgr_aStarCost(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     2, 12);
-\echo --q2
+/* -- q2 */
 SELECT * FROM pgr_aStarCost(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     2, 12,
     directed := false, heuristic := 2);
-\echo --q3
+/* -- q3 */
 SELECT * FROM pgr_aStarCost(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     2, ARRAY[3, 12], heuristic := 2);
-\echo --q4
+/* -- q4 */
 SELECT * FROM pgr_aStarCost(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     ARRAY[7, 2], 12, heuristic := 0);
-\echo --q5
+/* -- q5 */
 SELECT * FROM pgr_aStarCost(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     ARRAY[7, 2], ARRAY[3, 12], heuristic := 2);
-\echo --q6
+/* -- q6 */
 SELECT * FROM pgr_aStarCost(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     'SELECT * FROM ( VALUES (7, 3), (2, 12) ) AS t(source, target)',
     heuristic := 2);
-\echo --q7
+/* -- q7 */
