@@ -1,18 +1,18 @@
 ------------------------
 -- pgr_aStar
 ------------------------
-\echo -- astar q1
+/* -- q astar q1 */
 SELECT * FROM pgr_aStarCostMatrix(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5)
 );
-\echo -- astar q2
+/* -- q astar q2 */
 SELECT * FROM pgr_aStarCostMatrix(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5),
     directed := false, heuristic := 2
 );
-\echo -- astar q3
+/* -- q astar q3 */
 SELECT * FROM pgr_TSP(
     $$
     SELECT * FROM pgr_aStarCostMatrix(
@@ -23,4 +23,4 @@ SELECT * FROM pgr_TSP(
     $$,
     randomize := false
 );
-\echo -- astar q4
+/* -- q astar q4 */
