@@ -1,44 +1,44 @@
 
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_bdAstar(
     'SELECT id, source, target, cost, reverse_cost, x1,y1,x2,y2
     FROM edge_table',
     2, 3
 );
 
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_bdAstar(
     'SELECT id, source, target, cost, reverse_cost, x1,y1,x2,y2
     FROM edge_table',
     2, 3,
     true, heuristic := 2
 );
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_bdAstar(
     'SELECT id, source, target, cost, reverse_cost, x1,y1,x2,y2
     FROM edge_table',
     2, ARRAY[3, 11],
     heuristic := 3, factor := 3.5
 );
-\echo -- q4
+/* -- q4 */
 SELECT * FROM pgr_bdAstar(
     'SELECT id, source, target, cost, reverse_cost, x1,y1,x2,y2
     FROM edge_table',
     ARRAY[2, 7], 3,
     false, heuristic := 4
 );
-\echo -- q5
+/* -- q5 */
 SELECT * FROM pgr_bdAstar(
     'SELECT id, source, target, cost, reverse_cost, x1,y1,x2,y2
     FROM edge_table',
     ARRAY[2, 7], ARRAY[3, 11],
     factor := 0.5
 );
-\echo -- q6
+/* -- q6 */
 SELECT * FROM pgr_bdAstar(
     'SELECT id, source, target, cost, reverse_cost, x1,y1,x2,y2
     FROM edge_table',
     'SELECT * FROM ( VALUES (2, 3), (7, 11) ) AS t(source, target)',
     factor := 0.5
 );
-\echo -- q7
+ /* -- q7 */
