@@ -2,18 +2,18 @@ SET client_min_messages TO WARNING;
 ------------------------
 -- bdAstarCostMatrix
 ------------------------
-\echo -- bdAstar q1
+/* -- bdAstar q1 */
 SELECT * FROM pgr_bdAstarCostMatrix(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5)
 );
-\echo -- bdAstar q2
+/* -- bdAstar q2 */
 SELECT * FROM pgr_bdAstarCostMatrix(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5),
     false
 );
-\echo -- bdAstar q3
+/* -- bdAstar q3 */
 SELECT * FROM pgr_TSP(
     $$
     SELECT * FROM pgr_bdAstarCostMatrix(
@@ -24,4 +24,4 @@ SELECT * FROM pgr_TSP(
     $$,
     randomize := false
 );
-\echo -- bdAstar q4
+/* -- bdAstar q4 */
