@@ -1,30 +1,30 @@
 
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_bdDijkstraCost(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3
 );
 
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_bdDijkstraCost(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
     false
 );
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_bdDijkstraCost(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, ARRAY[3, 11]);
-\echo -- q4
+/* -- q4 */
 SELECT * FROM pgr_bdDijkstraCost(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2, 7], 3);
-\echo -- q5
+/* -- q5 */
 SELECT * FROM pgr_bdDijkstraCost(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2, 7], ARRAY[3, 11]);
-\echo -- q6
+/* -- q6 */
 SELECT * FROM pgr_bdDijkstraCost(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     'SELECT * FROM ( VALUES (2, 3), (7, 11) ) AS t(source, target)');
-\echo -- q7
+/* -- q7 */
