@@ -2,18 +2,18 @@ SET client_min_messages TO WARNING;
 ------------------------
 -- bddijkstraCostMatrix
 ------------------------
-\echo -- bdDijkstra q1
+/* -- bdDijkstra q1 */
 SELECT * FROM pgr_bdDijkstraCostMatrix(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5)
 );
-\echo -- bdDijkstra q2
+/* -- bdDijkstra q2 */
 SELECT * FROM pgr_bdDijkstraCostMatrix(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5),
     false
 );
-\echo -- bdDijkstra q3
+/* -- bdDijkstra q3 */
 SELECT * FROM pgr_TSP(
     $$
     SELECT * FROM pgr_bdDijkstraCostMatrix(
@@ -24,4 +24,4 @@ SELECT * FROM pgr_TSP(
     $$,
     randomize := false
 );
-\echo -- bdDijkstra q4
+/* -- bdDijkstra q4 */
