@@ -1,35 +1,35 @@
 
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_bellmanFord(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3
 );
 
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_bellmanFord(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
     FALSE
 );
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_bellmanFord(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, ARRAY[3,5],
     FALSE
 );
-\echo -- q4
+/* -- q4 */
 SELECT * FROM pgr_bellmanFord(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2,11], 5
 );
-\echo -- q5
+/* -- q5 */
 SELECT * FROM pgr_bellmanFord(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2,11], ARRAY[3,5]
 );
-\echo -- q6
+/* -- q6 */
 SELECT * FROM pgr_bellmanFord(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     'SELECT * FROM ( VALUES (2, 3), (11, 5) ) AS t(source, target)'
 );
-\echo -- q7
+/* -- q7 */
