@@ -1,21 +1,21 @@
-\echo --q1
+/* --q1 */
 SELECT * FROM pgr_breadthFirstSearch(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     2
 );
-\echo --q2
+/* --q2 */
 SELECT * FROM pgr_breadthFirstSearch(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     ARRAY[11,12], max_depth := 2
 );
-\echo --q3
+/* --q3 */
 SELECT * FROM pgr_breadthFirstSearch(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     ARRAY[11,12], max_depth := 2, directed := false
 );
-\echo --q4
+/* --q4 */
 SELECT * FROM pgr_breadthFirstSearch(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     -10
 );
-\echo --q5
+/* --q5 */
