@@ -1,21 +1,21 @@
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[1, 2]);
 
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
 ARRAY[1, 2], forbidden_vertices:=ARRAY[2]);
 
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
 ARRAY[1]);
 
-\echo -- q4
+/* -- q4 */
  SELECT * FROM pgr_contraction(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
 ARRAY[2]);
 
-\echo -- q5
+/* -- q5 */
