@@ -1,39 +1,39 @@
 
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3
 );
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
     FALSE
 );
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost FROM edge_table',
     2, ARRAY[3,5],
     FALSE
 );
-\echo -- q4
+/* -- q4 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2,11], 5
 );
-\echo -- q5
+/* -- q5 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2,11], ARRAY[3,5],
     FALSE
 );
-\echo -- q6
+/* -- q6 */
 
 
 -- Examples for :ref:`fig1-direct-Cost-Reverse`
 -------------------------------------------------------------------------------
 
-\echo -- q7
+/* -- q7 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3
@@ -66,14 +66,14 @@ SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     'SELECT * FROM (VALUES (2, 3), (2, 5), (11, 3), (11, 5)) AS combinations (source, target)'
 );
-\echo -- q8
+/* -- q8 */
 
 
 -- Examples for :ref:`fig2-undirect-Cost-Reverse`
 -------------------------------------------------------------------------------
 
 
-\echo -- q9
+/* -- q9 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
@@ -114,14 +114,14 @@ SELECT * FROM pgr_dijkstra(
     'SELECT * FROM (VALUES (2, 3), (2, 5), (11, 3), (11, 5)) AS combinations (source, target)',
     FALSE
 );
-\echo -- q10
+/* -- q10 */
 
 
 -- Examples for :ref:`fig3-direct-Cost`
 -------------------------------------------------------------------------------
 
 
-\echo -- q11
+/* -- q11 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost FROM edge_table',
     2, 3
@@ -154,13 +154,13 @@ SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost FROM edge_table',
     'SELECT * FROM (VALUES (2, 3), (2, 5), (11, 3), (11, 5)) AS combinations (source, target)'
 );
-\echo -- q12
+/* -- q12 */
 
 
 -- Examples for :ref:`fig4-undirect-Cost`
 -------------------------------------------------------------------------------
 
-\echo -- q13
+/* -- q13 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost FROM edge_table',
     2, 3,
@@ -201,7 +201,7 @@ SELECT * FROM pgr_dijkstra(
     'SELECT * FROM (VALUES (2, 3), (2, 5), (11, 3), (11, 5)) AS combinations (source, target)',
     FALSE
 );
-\echo -- q14
+/* -- q14 */
 
 
 
@@ -209,7 +209,7 @@ SELECT * FROM pgr_dijkstra(
 -- Equivalences for :ref:`fig1-direct-Cost-Reverse`
 -------------------------------------------------------------------------------
 
-\echo -- q15
+/* -- q15 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
@@ -241,14 +241,14 @@ SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     'SELECT * FROM (VALUES(2, 3)) AS combinations (source, target)'
 );
-\echo -- q16
+/* -- q16 */
 
 
 -- Equivalences for :ref:`fig2-undirect-Cost-Reverse`
 -------------------------------------------------------------------------------
 
 
-\echo -- q17
+/* -- q17 */
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
@@ -274,12 +274,12 @@ SELECT * FROM pgr_dijkstra(
     'SELECT * FROM (VALUES(2, 3)) AS combinations (source, target)',
     FALSE
 );
-\echo -- q18
+/* -- q18 */
 
 -- pgr_dijkstra combinations SQL
 -------------------------------------------------------------------------------
 
-\echo -- q19
+/* -- q19 */
 
 SELECT * FROM pgr_dijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
@@ -287,5 +287,5 @@ SELECT * FROM pgr_dijkstra(
     FALSE
 );
 
-\echo -- q20
+/* -- q20 */
 
