@@ -2,18 +2,18 @@ SET client_min_messages TO WARNING;
 ------------------------
 -- dijkstra
 ------------------------
-\echo -- dijkstra q1
+/* -- dijkstra q1 */
 SELECT * FROM pgr_dijkstraCostMatrix(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5)
 );
-\echo -- dijkstra q2
+/* -- dijkstra q2 */
 SELECT * FROM pgr_dijkstraCostMatrix(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     (SELECT array_agg(id) FROM edge_table_vertices_pgr WHERE id < 5),
     false
 );
-\echo -- dijkstra q3
+/* -- dijkstra q3 */
 SELECT * FROM pgr_TSP(
     $$
     SELECT * FROM pgr_dijkstraCostMatrix(
@@ -24,4 +24,4 @@ SELECT * FROM pgr_TSP(
     $$,
     randomize := false
 );
-\echo -- dijkstra q4
+/* -- dijkstra q4 */
