@@ -1,39 +1,39 @@
 
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_edgeDisjointPaths(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     3, 5
 );
 
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_edgeDisjointPaths(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     3, 5,
     directed := false
 );
 
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_edgeDisjointPaths(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     3, ARRAY[4, 5, 10]
 );
 
-\echo -- q4
+/* -- q4 */
 SELECT * FROM pgr_edgeDisjointPaths(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[3, 6], 5
 );
 
-\echo -- q5
+/* -- q5 */
 SELECT * FROM pgr_edgeDisjointPaths(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[3, 6], ARRAY[4, 5, 10]
 );
 
-\echo -- q6
+/* -- q6 */
 SELECT * FROM pgr_edgeDisjointPaths(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     'SELECT * FROM ( VALUES (3, 4), (6, 5), (3, 10) ) AS t(source, target)'
 );
 
-\echo -- q7
+/* -- q7 */
