@@ -1,13 +1,13 @@
 
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_maxCardinalityMatch(
     'SELECT id, source, target, cost AS going, reverse_cost AS coming FROM edge_table'
 );
 
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_maxCardinalityMatch(
     'SELECT id, source, target, cost AS going, reverse_cost AS coming FROM edge_table',
     directed := false
 );
 
-\echo -- q3
+/* -- q3 */
