@@ -3,7 +3,7 @@
 
 
 
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_maxFlow(
     'SELECT id,
             source,
@@ -14,7 +14,7 @@ SELECT * FROM pgr_maxFlow(
     , 6, 11
 );
 
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_maxFlow(
     'SELECT id,
             source,
@@ -25,7 +25,7 @@ SELECT * FROM pgr_maxFlow(
     , 6, ARRAY[11, 1, 13]
 );
 
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_maxFlow(
     'SELECT id,
             source,
@@ -36,7 +36,7 @@ SELECT * FROM pgr_maxFlow(
     , ARRAY[6, 8, 12], 11
 );
 
-\echo -- q4
+/* -- q4 */
 SELECT * FROM pgr_maxFlow(
     'SELECT id,
             source,
@@ -47,7 +47,7 @@ SELECT * FROM pgr_maxFlow(
     , ARRAY[6, 8, 12], ARRAY[1, 3, 11]
 );
 
-\echo -- q5
+/* -- q5 */
 SELECT * FROM pgr_maxFlow(
     'SELECT id,
             source,
@@ -58,4 +58,4 @@ SELECT * FROM pgr_maxFlow(
     'SELECT * FROM ( VALUES (6, 1), (8, 3), (12, 11), (8, 1) ) AS t(source, target)'
 );
 
-\echo -- q6
+/* -- q6 */
