@@ -1,11 +1,11 @@
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_primDD(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     2, 3.5
 );
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_primDD(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     ARRAY[13,2], 3.5
 );
-\echo -- q3
+/* -- q3 */
