@@ -1,8 +1,8 @@
-\echo --q1
+/* --q1 */
 	SELECT pgr_analyzeOneWay('edge_table',
         ARRAY['', 'B', 'TF'],
         ARRAY['', 'B', 'FT'],
         ARRAY['', 'B', 'FT'],
         ARRAY['', 'B', 'TF'],
         oneway:='dir');
-\echo --q1.1
+/* --q1.1 */
