@@ -1,33 +1,33 @@
 SET extra_float_digits=-3;
 
-\echo --e1
+/* --e1 */
 SELECT * FROM pgr_withPoints(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, -3);
-\echo --e2
+/* --e2 */
 SELECT * FROM pgr_withPoints(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, 3,
     details := true);
-\echo --e3
+/* --e3 */
 SELECT * FROM pgr_withPoints(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, ARRAY[-3,5]);
-\echo --e4
+/* --e4 */
 SELECT * FROM pgr_withPoints(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     ARRAY[-1,2], -3);
-\echo --e5
+/* --e5 */
 SELECT * FROM pgr_withPoints(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     ARRAY[-1,2], ARRAY[-3,7]);
 
-\echo --q2
+/* --q2 */
 SELECT ('(' || start_pid || ' => ' || end_pid ||') at ' || path_seq || 'th step:')::TEXT AS path_at,
         CASE WHEN edge = -1 THEN ' visits'
             ELSE ' passes in front of'
@@ -43,7 +43,7 @@ SELECT ('(' || start_pid || ' => ' || end_pid ||') at ' || path_seq || 'th step:
         driving_side := 'r',
         details := true)
     WHERE node IN (-6,6);
-\echo --q3
+/* --q3 */
 SELECT ('(' || start_pid || ' => ' || end_pid ||') at ' || path_seq || 'th step:')::TEXT AS path_at,
         CASE WHEN edge = -1 THEN ' visits'
             ELSE ' passes in front of'
@@ -59,14 +59,14 @@ SELECT ('(' || start_pid || ' => ' || end_pid ||') at ' || path_seq || 'th step:
         driving_side := 'l',
         details := true)
     WHERE node IN (-6,6);
-\echo --q4
+/* --q4 */
 SELECT * FROM pgr_withPoints(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     ARRAY[-1,2], ARRAY[-3,7],
     directed := false,
     details := true);
-\echo --q5
+/* --q5 */
 
 
 SELECT * FROM pgr_withPoints(
@@ -75,4 +75,4 @@ SELECT * FROM pgr_withPoints(
     'SELECT * FROM ( VALUES (-1, 3), (2, -3) ) AS t(source, target)',
     driving_side => 'r',
     details => true);
-\echo --q6
+/* --q6 */
