@@ -4,17 +4,17 @@
 SET extra_float_digits=-3;
 SET client_min_messages to WARNING;
 
-\echo -- withPoints q1
+/* -- withPoints q1 */
 SELECT * FROM pgr_withPointsCostMatrix(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction from pointsOfInterest',
     array[-1, 3, 6, -6]);
-\echo -- withPoints q2
+/* -- withPoints q2 */
 SELECT * FROM pgr_withPointsCostMatrix(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction from pointsOfInterest',
     array[-1, 3, 6, -6], directed := false);
-\echo -- withPoints q3
+/* -- withPoints q3 */
 SELECT * FROM pgr_TSP(
     $$
     SELECT * FROM pgr_withPointsCostMatrix(
@@ -24,4 +24,4 @@ SELECT * FROM pgr_TSP(
     $$,
     randomize := false
 );
-\echo -- withPoints q4
+/* -- withPoints q4 */
