@@ -1,29 +1,29 @@
 SET extra_float_digits=-3;
 
-\echo --q1
+/* --q1 */
 SELECT * FROM pgr_withPointsDD(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, 3.8);
-\echo --q2
+/* --q2 */
 SELECT * FROM pgr_withPointsDD(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, 3.8,
     driving_side := 'r',
     details := true);
-\echo --q3
+/* --q3 */
 SELECT * FROM pgr_withPointsDD(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, 3.8,
     driving_side := 'l',
     details := true);
-\echo --q4
+/* --q4 */
 SELECT * FROM pgr_withPointsDD(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, 3.8,
     driving_side := 'b',
     details := true);
-\echo --q5
+/* --q5 */
