@@ -1,26 +1,26 @@
 SET extra_float_digits=-3;
 
-\echo --q1
+/* --q1 */
 SELECT * FROM pgr_withPointsKSP(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, -2, 2);
-\echo --q2
+/* --q2 */
 SELECT * FROM pgr_withPointsKSP(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, 6, 2, details := true);
-\echo --q3
+/* --q3 */
 SELECT * FROM pgr_withPointsKSP(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, -2, 2,
     driving_side := 'l', details := true);
-\echo --q4
+/* --q4 */
 SELECT * FROM pgr_withPointsKSP(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, -2, 2,
     heap_paths := true, driving_side := 'r', details := true);
-\echo --q5
+/* --q5 */
 
