@@ -20,15 +20,18 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #ifndef INCLUDE_C_COMMON_POINTS_INPUT_H_
 #define INCLUDE_C_COMMON_POINTS_INPUT_H_
 #pragma once
 
-#include "c_types/point_on_edge_t.h"
+/* for size-t */
+#include <stddef.h>
 
-/*! @brief pgr_get_points 
+typedef struct Point_on_edge_t Point_on_edge_t;
+
+/*! @brief pgr_get_points
 
 For queries of the type:
 ~~~~{.c}
