@@ -33,15 +33,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 /* for size-t */
 #ifdef __cplusplus
 #   include <cstddef>
+#   include <cstdint>
+using Edge_xy_t = struct Edge_xy_t;
+using II_t_rt = struct II_t_rt;
+using Path_rt = struct Path_rt;
 #else
 #   include <stddef.h>
+#   include <stdint.h>
+typedef struct Edge_xy_t Edge_xy_t;
+typedef struct II_t_rt II_t_rt;
+typedef struct Path_rt Path_rt;
 #endif
 
-#include "c_types/pgr_edge_xy_t.h"
-#include "c_types/pgr_combination_t.h"
-#include "c_types/general_path_element_t.h"
-
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -53,10 +56,10 @@ extern "C" {
       end_vid BIGINT  directed BOOLEAN DEFAULT true,
      ********************************************************/
     void do_pgr_astarManyToMany(
-            Pgr_edge_xy_t  *data_edges,
+            Edge_xy_t  *data_edges,
             size_t total_edges,
 
-            pgr_combination_t  *combinations,
+            II_t_rt  *combinations,
             size_t total_combinations,
 
             int64_t  *start_vidsArr, size_t size_start_vidsArr,
@@ -67,7 +70,7 @@ extern "C" {
             double epsilon,
             bool only_cost,
             bool normal,
-            General_path_element_t **return_tuples,
+            Path_rt **return_tuples,
             size_t *return_count,
             char** log_msg,
             char** notice_msg,
