@@ -4,9 +4,9 @@ File: withPoints_driver.h
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
 
-Function's developer: 
+Function's developer:
 Copyright (c) 2015 Celia Virginia Vergara Castillo
-Mail: 
+Mail:
 
 ------
 
@@ -24,16 +24,26 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #ifndef INCLUDE_DRIVERS_DRIVING_DISTANCE_WITHPOINTS_DD_DRIVER_H_
 #define INCLUDE_DRIVERS_DRIVING_DISTANCE_WITHPOINTS_DD_DRIVER_H_
 #pragma once
 
-#include "c_types/point_on_edge_t.h"
-#include "c_types/pgr_edge_t.h"
-#include "c_types/general_path_element_t.h"
-
+/* for size-t */
+#ifdef __cplusplus
+#   include <cstddef>
+#   include <cstdint>
+using Point_on_edge_t = struct Point_on_edge_t;
+using Edge_t = struct Edge_t;
+using Path_rt = struct Path_rt;
+#else
+#   include <stddef.h>
+#   include <stdint.h>
+typedef struct Point_on_edge_t Point_on_edge_t;
+typedef struct Edge_t Edge_t;
+typedef struct Path_rt Path_rt;
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -41,9 +51,9 @@ extern "C" {
 
 
     void do_pgr_many_withPointsDD(
-            pgr_edge_t      *edges,             size_t total_edges,
+            Edge_t      *edges,             size_t total_edges,
             Point_on_edge_t *points_p,          size_t total_points,
-            pgr_edge_t      *edges_of_points,   size_t total_edges_of_points,
+            Edge_t      *edges_of_points,   size_t total_edges_of_points,
 
             int64_t  *start_pids_arr,    size_t s_len,
             double distance,
@@ -53,7 +63,7 @@ extern "C" {
             bool details,
             bool equiCost,
 
-            General_path_element_t **return_tuples, size_t *return_count,
+            Path_rt **return_tuples, size_t *return_count,
             char** log_msg,
             char** notice_msg,
             char ** err_msg);
