@@ -32,15 +32,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 /* for size-t */
 #ifdef __cplusplus
+#   include <cstdint>
 #   include <cstddef>
+using Point_on_edge_t = struct Point_on_edge_t;
+using Edge_t = struct Edge_t;
+using Path_rt = struct Path_rt;
 #else
 #   include <stddef.h>
+#   include <stdint.h>
+typedef struct Point_on_edge_t Point_on_edge_t;
+typedef struct Edge_t Edge_t;
+typedef struct Path_rt Path_rt;
 #endif
 
-#include "c_types/point_on_edge_t.h"
-#include "c_types/pgr_edge_t.h"
-#include "c_types/general_path_element_t.h"
-
 
 #ifdef __cplusplus
 extern "C" {
@@ -53,9 +57,9 @@ extern "C" {
     //  end_pid BIGINT,
     //  directed BOOLEAN DEFAULT true,
     int do_pgr_withPointsKsp(
-            pgr_edge_t  *edges,             size_t total_edges,
+            Edge_t  *edges,             size_t total_edges,
             Point_on_edge_t  *points,       size_t total_points,
-            pgr_edge_t  *edges_of_points,   size_t total_edges_of_points,
+            Edge_t  *edges_of_points,   size_t total_edges_of_points,
             int64_t start_pid,
             int64_t end_pid,
             size_t k,
@@ -64,7 +68,7 @@ extern "C" {
             char driving_side,
             bool details,
 
-            General_path_element_t **return_tuples,
+            Path_rt **return_tuples,
             size_t *return_count,
             char ** log_msg,
             char ** notice_msg,
