@@ -106,8 +106,6 @@ class Vehicle_node: public Tw_node {
 
      ///@}
 
-     /*! \brief True when \b arrival_time + \b delta_time generates TWV.*/
-     bool deltaGeneratesTWV(double delta_time) const;
 
      /** @name State */
      ///@ {
@@ -142,15 +140,6 @@ class Vehicle_node: public Tw_node {
      void evaluate(const Vehicle_node &pred, double cargoLimit, double speed);
      ///@}
 
-     /** @name Document*/
-     ///@ {
-
-     /*! \brief returns the arrval time at \b this visited after \b other */
-     double arrival_i_arrives_j(
-             const Vehicle_node &other,
-             double speed) const;
-
-     ///@}
 
 
 
