@@ -1,5 +1,5 @@
 
-\i setup.sql
+BEGIN;
 
 SET client_min_messages TO WARNING;
 
