@@ -1,5 +1,5 @@
-\i setup.sql
-\i dijkstra_pgtap_tests.sql
+BEGIN;
+
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT CASE WHEN min_version('3.1.0') THEN plan(81) ELSE plan(68) END;
