@@ -1,5 +1,5 @@
-\i setup.sql
-\i flow_pgtap_tests.sql
+BEGIN;
+
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT CASE WHEN NOT min_version('3.2.0') THEN plan(68) ELSE plan(81) END;
