@@ -1,4 +1,4 @@
-\i setup.sql
+BEGIN;
 SET client_min_messages TO WARNING;
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
