@@ -20,7 +20,7 @@ along with this program; if not, write TO the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 ********************************************************************PGR-GNU*/
-\i setup.sql
+BEGIN;
 
 SELECT PLAN(95);
 
