@@ -1,4 +1,4 @@
-\i setup.sql
+BEGIN;
 
 SELECT plan(1);
 UPDATE edge_table SET cost = sign(cost) + 0.001 * id * id, reverse_cost = sign(reverse_cost) + 0.001 * id * id;
