@@ -1,6 +1,6 @@
 
-\i setup.sql
-\i tsp_pgtap_tests.sql
+BEGIN;
+SET client_min_messages TO WARNING;
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT CASE WHEN min_version('4.0.0') THEN plan(1) ELSE plan(9) END;
