@@ -1,5 +1,5 @@
-\i setup.sql
-\i tsp_pgtap_tests.sql
+BEGIN;
+SET client_min_messages TO WARNING;
 
 SELECT plan(5);
 SELECT tsp_types_check('pgr_tsp');
