@@ -111,6 +111,25 @@ CREATE FUNCTION pgr_edmondsKarp(
   $BODY$
   LANGUAGE sql VOLATILE STRICT;
 
+-- COMBINATIONS
+--v3.2
+CREATE FUNCTION pgr_edmondsKarp(
+    TEXT, -- edges_sql (required)
+    TEXT, -- combinations_sql (required)
+
+    OUT seq INTEGER,
+    OUT edge BIGINT,
+    OUT start_vid BIGINT,
+    OUT end_vid BIGINT,
+    OUT flow BIGINT,
+    OUT residual_capacity BIGINT)
+  RETURNS SEtoF RECORD AS
+  $BODY$
+        SELECT *
+        FROM _pgr_maxflow(_pgr_get_statement($1), _pgr_get_statement($2), 3);
+  $BODY$
+  LANGUAGE sql VOLATILE STRICT;
+
 
 -- COMMENTS
 
@@ -161,3 +180,13 @@ IS 'pgr_edmondsKarp(Many to Many)
 - Documentation:
   - ${PROJECT_DOC_LINK}/pgr_edmondsKarp.html
 ';
+
+COMMENT ON FUNCTION pgr_edmondsKarp(TEXT, TEXT)
+IS 'pgr_edmondsKarp(Combinations)
+- Directed graph
+- Parameters:
+  - Edges SQL with columns: id, source, target, capacity [,reverse_capacity]
+  - Combinations SQL with columns: source, target
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_edmondsKarp.html
+';
