@@ -1,4 +1,5 @@
 /*PGR-GNU*****************************************************************
+FILE: maxCardinalityMatch.sql
 
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
@@ -22,18 +23,35 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
---FUNCTIONS
+--v2.6
+CREATE FUNCTION pgr_maxCardinalityMatch(
+    TEXT, -- edges_sql (required)
+
+    directed BOOLEAN DEFAULT true,
 
-CREATE OR REPLACE FUNCTION pgr_maxCardinalityMatch(
-    edges_sql TEXT,
-    directed BOOLEAN DEFAULT TRUE,
     OUT seq INTEGER,
     OUT edge BIGINT,
     OUT source BIGINT,
-    OUT target BIGINT
-    )
-  RETURNS SETOF RECORD AS
- '${MODULE_PATHNAME}', 'maximum_cardinality_matching'
-    LANGUAGE c VOLATILE STRICT;
+    OUT target BIGINT)
+RETURNS SETOF RECORD AS
+$BODY$
+    SELECT *
+    FROM _pgr_maxCardinalityMatch(_pgr_get_statement($1), $2)
+$BODY$
+LANGUAGE SQL VOLATILE STRICT
+COST 100
+ROWS 1000;
+
+-- COMMENTS
+
+COMMENT ON FUNCTION pgr_maxCardinalityMatch(TEXT, BOOLEAN)
+IS 'pgr_maxCardinalityMatch
+- Parameters:
+  - Edges SQL with columns: id, source, target, going [,coming]
+- Optional Parameters:
+  - directed := true
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_maxCardinalityMatch.html
+';
