@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <algorithm>
 #include <utility>
 
-#include "c_types/general_path_element_t.h"
+#include "c_types/path_rt.h"
 #include "cpp_common/pgr_assert.h"
 
 
@@ -219,7 +219,7 @@ void Path::append(const Path &other) {
 
 
 void Path::generate_postgres_data(
-        General_path_element_t **postgres_data,
+        Path_rt **postgres_data,
         size_t &sequence) const {
     int i = 1;
     for (const auto e : path) {
@@ -237,7 +237,7 @@ void Path::generate_postgres_data(
 
 /* used by driving distance */
 void Path::get_pg_dd_path(
-        General_path_element_t **ret_path,
+        Path_rt **ret_path,
         size_t &sequence) const {
     for (unsigned int i = 0; i < path.size(); i++) {
         (*ret_path)[sequence].seq = static_cast<int>(i);
@@ -253,7 +253,7 @@ void Path::get_pg_dd_path(
 
 /* used by ksp */
 void Path::get_pg_ksp_path(
-        General_path_element_t **ret_path,
+        Path_rt **ret_path,
         size_t &sequence, int routeId) const {
     for (unsigned int i = 0; i < path.size(); i++) {
         (*ret_path)[sequence].seq = static_cast<int>(i + 1);
@@ -271,7 +271,7 @@ void Path::get_pg_ksp_path(
 
 /* used by turn restricted */
 void Path::get_pg_turn_restricted_path(
-        General_path_element_t **ret_path,
+        Path_rt **ret_path,
         size_t &sequence, int routeId) const {
     for (unsigned int i = 0; i < path.size(); i++) {
         (*ret_path)[sequence].seq = static_cast<int>(i + 1);
@@ -308,7 +308,7 @@ Path::sort_by_node_agg_cost() {
 
 size_t
 collapse_paths(
-        General_path_element_t **ret_path,
+        Path_rt **ret_path,
         const std::deque< Path > &paths) {
     size_t sequence = 0;
     for (const Path &path : paths) {
