@@ -18,7 +18,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-aint64_t with this program; if not, write to the Free Software
+along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
@@ -30,7 +30,7 @@ namespace pgrouting {
 namespace trsp {
 
 EdgeInfo::EdgeInfo(
-            pgr_edge_t edgeIn,
+            Edge_t edgeIn,
             size_t edgeIndex) :
         m_edge(edgeIn),
         m_edgeIndex(edgeIndex),
