@@ -21,9 +21,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
-
+ ********************************************************************PGR-GNU*/
 
+#include <stdbool.h>
 #include "c_common/postgres_connection.h"
 #include "utils/array.h"
 
@@ -34,16 +34,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "c_common/e_report.h"
 #include "c_common/time_msg.h"
 
-#include "c_types/pgr_edge_t.h"
+#include "c_types/edge_t.h"
 #include "c_types/restriction_t.h"
-#include "c_types/general_path_element_t.h"
+#include "c_types/path_rt.h"
 
 #include "c_common/edges_input.h"
 #include "c_common/restrictions_input.h"
 #include "c_common/arrays_input.h"
 
-PGDLLEXPORT Datum turn_restriction(PG_FUNCTION_ARGS);
-PG_FUNCTION_INFO_V1(turn_restriction);
+PGDLLEXPORT Datum _trsp(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(_trsp);
 
 
 static
@@ -56,11 +56,11 @@ void compute_trsp(
 
         bool directed,
 
-        General_path_element_t **result_tuples,
+        Path_rt **result_tuples,
         size_t *result_count) {
     pgr_SPI_connect();
 
-    pgr_edge_t *edges = NULL;
+    Edge_t *edges = NULL;
     size_t total_edges = 0;
     pgr_get_edges(edges_sql, &edges, &total_edges);
 
@@ -68,14 +68,12 @@ void compute_trsp(
     size_t total_restrictions = 0;
     pgr_get_restrictions(restrictions_sql, &restrictions, &total_restrictions);
 
-    int64_t* start_vidsArr = NULL;
     size_t size_start_vidsArr = 0;
-    start_vidsArr = (int64_t*)
+    int64_t* start_vidsArr = (int64_t*)
         pgr_get_bigIntArray(&size_start_vidsArr, starts);
 
-    int64_t* end_vidsArr = NULL;
     size_t size_end_vidsArr = 0;
-    end_vidsArr = (int64_t*)
+    int64_t* end_vidsArr = (int64_t*)
         pgr_get_bigIntArray(&size_end_vidsArr, ends);
 
     PGR_DBG("Starting timer");
@@ -117,12 +115,12 @@ void compute_trsp(
 
 
 PGDLLEXPORT Datum
-turn_restriction(PG_FUNCTION_ARGS) {
+_trsp(PG_FUNCTION_ARGS) {
     FuncCallContext     *funcctx;
     TupleDesc            tuple_desc;
 
     size_t result_count             = 0;
-    General_path_element_t  *result_tuples   = NULL;
+    Path_rt  *result_tuples   = NULL;
 
     // stuff done only on the first call of the function
     if (SRF_IS_FIRSTCALL()) {
@@ -163,7 +161,7 @@ turn_restriction(PG_FUNCTION_ARGS) {
     funcctx = SRF_PERCALL_SETUP();
 
     tuple_desc = funcctx->tuple_desc;
-    result_tuples = (General_path_element_t *) funcctx->user_fctx;
+    result_tuples = (Path_rt *) funcctx->user_fctx;
 
     if (funcctx->call_cntr < funcctx->max_calls) {
         // do when there is more left to send
