@@ -6,10 +6,11 @@
 DIR=$(git rev-parse --show-toplevel)/sql/sigs
 
 pushd "${DIR}" > /dev/null || exit
-SIGNATURES=$(git ls-files *.sig | perl -pe 's/pgrouting--(.*)\.sig/$1/')
-for s1 in ${SIGNATURES[@]}
+SIGNATURES=$(git ls-files "*.sig" | perl -pe 's/pgrouting--(.*)\.sig/$1/')
+
+for s1 in "${SIGNATURES[@]}"
 do
-    for s2 in ${SIGNATURES[@]}
+    for s2 in "${SIGNATURES[@]}"
     do
         # only comparing lower version with higher version
         if (( $(echo "$s1 >= $s2" | bc -l) )); then continue; fi
