@@ -31,14 +31,14 @@ BEGIN
         -- RAISE WARNING '%', q1;
 
 
-        RETURN query SELECT * FROM lives_ok(q1);
+        RETURN query SELECT * FROM lives_ok(q1, 'lives_ok' || q1);
         IF i = 0 THEN
-            RETURN query SELECT * FROM isnt_empty(q1);
+            RETURN query SELECT * FROM isnt_empty(q1, 'isnt_empty' || q1);
         ELSE
             IF func='pgr_alphashape' THEN
-                RETURN query SELECT * FROM isnt_empty(q1);
+                RETURN query SELECT * FROM isnt_empty(q1, 'isnt_empty' || q1);
             ELSE
-                RETURN query SELECT * FROM is_empty(q1);
+                RETURN query SELECT * FROM is_empty(q1, 'is_empty' || q1);
             END IF;
         END IF;
 
