@@ -12,7 +12,7 @@ DOCDIR="doc/i18n"
 
 LANGUAGES='de es ja fr'
 
-if [ $1 ]; then
+if [ "$1" ]; then
 	LANGUAGES=$1
 fi
 
@@ -27,7 +27,7 @@ echo "*************************************************************************"
 echo "Build HTML documentation"
 echo "*************************************************************************"
 for i in ${LANGUAGES}; do
-	sphinx-build -b html -a -E -D language="${i}" -c "${CONFIG}" ${ROOT} build/doc/html/${i}
+	sphinx-build -b html -a -E -D language="${i}" -c "${CONFIG}" "${ROOT}" "build/doc/html/${i}"
 done
 
 echo "*************************************************************************"
@@ -35,15 +35,15 @@ echo "Build LATEX documentation"
 echo "*************************************************************************"
 for i in ${LANGUAGES}; do
 	DESTINATION="build/doc/latex/${i}"
-	sphinx-build -b html -a -E -D language="${i}" -c "${CONFIG}" ${ROOT} ${DESTINATION}
-	cd "${DESTINATION}"
+	sphinx-build -b html -a -E -D language="${i}" -c "${CONFIG}" "${ROOT}" "${DESTINATION}"
+	cd "${DESTINATION}" || exit 1
 	pdflatex -interaction=nonstopmode pgRoutingDocumentation.tex > /dev/null 2>&1
-	cd "${ROOT}"
+	cd "${ROOT}" || exit 1
 done
 
 echo "*************************************************************************"
 echo "Build MAN documentation"
 echo "*************************************************************************"
 for i in ${LANGUAGES}; do
-	sphinx-build -b html -a -E -D language="${i}" -c "${CONFIG}" ${ROOT} build/doc/man/${i}
+	sphinx-build -b html -a -E -D language="${i}" -c "${CONFIG}" "${ROOT}" "build/doc/man/${i}"
 done
